# Generated by Django 4.2.24 on 2025-09-22 11:51

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('valar', '0002_location'),
    ]

    operations = [
        migrations.AddField(
            model_name='location',
            name='code',
            field=models.CharField(max_length=100, null=True),
        ),
        migrations.AddField(
            model_name='location',
            name='name_cn',
            field=models.CharField(max_length=100, null=True),
        ),
        migrations.AddField(
            model_name='location',
            name='name_en',
            field=models.CharField(max_length=100, null=True),
        ),
    ]
