# Generated by Django 4.2.24 on 2025-09-22 11:52

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('valar', '0003_location_code_location_name_cn_location_name_en'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='location',
            name='icon',
        ),
        migrations.RemoveField(
            model_name='location',
            name='isLeaf',
        ),
        migrations.RemoveField(
            model_name='location',
            name='pid',
        ),
    ]
