# Generated by Django 4.2.24 on 2025-09-22 11:51

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('valar', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='Location',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('sort', models.BigIntegerField(null=True, verbose_name='序号')),
                ('create_time', models.DateTimeField(auto_now_add=True, null=True, verbose_name='创建时间')),
                ('modify_time', models.DateTimeField(auto_now=True, null=True, verbose_name='修改时间')),
                ('disabled', models.BooleanField(default=False, verbose_name='禁用')),
                ('saved', models.BooleanField(default=False, verbose_name='已保存')),
                ('pid', models.IntegerField(default=0, verbose_name='父节点')),
                ('isLeaf', models.BooleanField(default=False, verbose_name='叶子节点')),
                ('icon', models.CharField(max_length=255, null=True, verbose_name='图标')),
                ('scope', models.CharField(max_length=100, null=True)),
                ('name', models.CharField(max_length=100, null=True)),
            ],
            options={
                'verbose_name': '指标集',
            },
        ),
    ]
